==> jc-1.4.0.tar.gz: java/util/jar/Attributes__24Name.h <==
// public class java.util.jar.Attributes$Name

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2b9bd9a38c64cf97 java_util_jar_Attributes__24Name

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_jar_Attributes__24Name_H_
#define _JC_java_util_jar_Attributes__24Name_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_jar_Attributes__24Name$object;

// Typedefs
typedef struct _jc_java_util_jar_Attributes__24Name$sub_refs	_jc_java_util_jar_Attributes__24Name$sub_refs;
typedef struct _jc_java_util_jar_Attributes__24Name$sub_nonrefs	_jc_java_util_jar_Attributes__24Name$sub_nonrefs;
typedef struct _jc_java_util_jar_Attributes__24Name$refs	_jc_java_util_jar_Attributes__24Name$refs;
typedef struct _jc_java_util_jar_Attributes__24Name$nonrefs	_jc_java_util_jar_Attributes__24Name$nonrefs;
typedef struct _jc_java_util_jar_Attributes__24Name$object	_jc_java_util_jar_Attributes__24Name$object;

typedef struct _jc_java_util_jar_Attributes__24Name$fields_struct	_jc_java_util_jar_Attributes__24Name$fields_struct;
typedef const struct _jc_java_util_jar_Attributes__24Name$vmethods	_jc_java_util_jar_Attributes__24Name$vmethods;
typedef const struct _jc_java_util_jar_Attributes__24Name$vtable	_jc_java_util_jar_Attributes__24Name$vtable;
typedef const struct _jc_java_util_jar_Attributes__24Name$vtype	_jc_java_util_jar_Attributes__24Name$vtype;

// Class fields structure
struct _jc_java_util_jar_Attributes__24Name$fields_struct {
	struct _jc_java_util_jar_Attributes__24Name$object	*CLASS__5fPATH;
	struct _jc_java_util_jar_Attributes__24Name$object	*CONTENT__5fTYPE;
	struct _jc_java_util_jar_Attributes__24Name$object	*EXTENSION__5fINSTALLATION;
	struct _jc_java_util_jar_Attributes__24Name$object	*EXTENSION__5fLIST;
	struct _jc_java_util_jar_Attributes__24Name$object	*EXTENSION__5fNAME;
	struct _jc_java_util_jar_Attributes__24Name$object	*IMPLEMENTATION__5fTITLE;
	struct _jc_java_util_jar_Attributes__24Name$object	*IMPLEMENTATION__5fURL;
	struct _jc_java_util_jar_Attributes__24Name$object	*IMPLEMENTATION__5fVENDOR;
	struct _jc_java_util_jar_Attributes__24Name$object	*IMPLEMENTATION__5fVENDOR__5fID;
	struct _jc_java_util_jar_Attributes__24Name$object	*IMPLEMENTATION__5fVERSION;
	struct _jc_java_util_jar_Attributes__24Name$object	*MAIN__5fCLASS;
	struct _jc_java_util_jar_Attributes__24Name$object	*MANIFEST__5fVERSION;
	struct _jc_java_util_jar_Attributes__24Name$object	*SEALED;
	struct _jc_java_util_jar_Attributes__24Name$object	*SIGNATURE__5fVERSION;
	struct _jc_java_util_jar_Attributes__24Name$object	*SPECIFICATION__5fTITLE;
	struct _jc_java_util_jar_Attributes__24Name$object	*SPECIFICATION__5fVENDOR;
	struct _jc_java_util_jar_Attributes__24Name$object	*SPECIFICATION__5fVERSION;
};
extern _jc_java_util_jar_Attributes__24Name$fields_struct _jc_java_util_jar_Attributes__24Name$class_fields;

// Constructors
extern void _jc_java_util_jar_Attributes__24Name$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_util_jar_Attributes__24Name$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_java_util_jar_Attributes__24Name$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_jar_Attributes__24Name$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_util_jar_Attributes__24Name$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_jar_Attributes__24Name$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_jar_Attributes__24Name$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_util_jar_Attributes__24Name$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_jar_Attributes__24Name$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_jar_Attributes__24Name$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_util_jar_Attributes__24Name$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_util_jar_Attributes__24Name$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_util_jar_Attributes__24Name$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_jar_Attributes__24Name$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_jar_Attributes__24Name$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_util_jar_Attributes__24Name$object *);
};

// Vtable
struct _jc_java_util_jar_Attributes__24Name$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_jar_Attributes__24Name$vmethods	java_util_jar_Attributes__24Name;
};

// Vtype
struct _jc_java_util_jar_Attributes__24Name$vtype {
	_jc_type			type;
	_jc_java_util_jar_Attributes__24Name$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_jar_Attributes__24Name$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*origName;
};

// Reference instance fields (object)
struct _jc_java_util_jar_Attributes__24Name$refs {
    _jc_java_util_jar_Attributes__24Name$sub_refs	java_util_jar_Attributes__24Name;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_jar_Attributes__24Name$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_jar_Attributes__24Name$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_jar_Attributes__24Name$sub_nonrefs	java_util_jar_Attributes__24Name;
};

// Object instance structure
struct _jc_java_util_jar_Attributes__24Name$object {
	_jc_java_util_jar_Attributes__24Name$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_jar_Attributes__24Name$vtype	*vtype;
	_jc_java_util_jar_Attributes__24Name$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_jar_Attributes__24Name$vtype _jc_java_util_jar_Attributes__24Name$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_jar_Attributes__24Name, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_jar_Attributes__24Name$class_object;

#endif	/* _JC_java_util_jar_Attributes__24Name_H_ */

==> jc-1.4.6.tar.gz: java/util/jar/Attributes__24Name.h <==
// public class java.util.jar.Attributes$Name

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2b9bd9a38c64cf97 java_util_jar_Attributes__24Name

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_jar_Attributes__24Name_H_
#define _JC_java_util_jar_Attributes__24Name_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_jar_Attributes__24Name$object;

// Typedefs
typedef struct _jc_java_util_jar_Attributes__24Name$sub_refs	_jc_java_util_jar_Attributes__24Name$sub_refs;
typedef struct _jc_java_util_jar_Attributes__24Name$sub_nonrefs	_jc_java_util_jar_Attributes__24Name$sub_nonrefs;
typedef struct _jc_java_util_jar_Attributes__24Name$refs	_jc_java_util_jar_Attributes__24Name$refs;
typedef struct _jc_java_util_jar_Attributes__24Name$nonrefs	_jc_java_util_jar_Attributes__24Name$nonrefs;
typedef struct _jc_java_util_jar_Attributes__24Name$object	_jc_java_util_jar_Attributes__24Name$object;

typedef struct _jc_java_util_jar_Attributes__24Name$fields_struct	_jc_java_util_jar_Attributes__24Name$fields_struct;
typedef const struct _jc_java_util_jar_Attributes__24Name$vmethods	_jc_java_util_jar_Attributes__24Name$vmethods;
typedef const struct _jc_java_util_jar_Attributes__24Name$vtable	_jc_java_util_jar_Attributes__24Name$vtable;
typedef const struct _jc_java_util_jar_Attributes__24Name$vtype	_jc_java_util_jar_Attributes__24Name$vtype;

// Class fields structure
struct _jc_java_util_jar_Attributes__24Name$fields_struct {
	struct _jc_java_util_jar_Attributes__24Name$object	*CLASS__5fPATH;
	struct _jc_java_util_jar_Attributes__24Name$object	*CONTENT__5fTYPE;
	struct _jc_java_util_jar_Attributes__24Name$object	*EXTENSION__5fINSTALLATION;
	struct _jc_java_util_jar_Attributes__24Name$object	*EXTENSION__5fLIST;
	struct _jc_java_util_jar_Attributes__24Name$object	*EXTENSION__5fNAME;
	struct _jc_java_util_jar_Attributes__24Name$object	*IMPLEMENTATION__5fTITLE;
	struct _jc_java_util_jar_Attributes__24Name$object	*IMPLEMENTATION__5fURL;
	struct _jc_java_util_jar_Attributes__24Name$object	*IMPLEMENTATION__5fVENDOR;
	struct _jc_java_util_jar_Attributes__24Name$object	*IMPLEMENTATION__5fVENDOR__5fID;
	struct _jc_java_util_jar_Attributes__24Name$object	*IMPLEMENTATION__5fVERSION;
	struct _jc_java_util_jar_Attributes__24Name$object	*MAIN__5fCLASS;
	struct _jc_java_util_jar_Attributes__24Name$object	*MANIFEST__5fVERSION;
	struct _jc_java_util_jar_Attributes__24Name$object	*SEALED;
	struct _jc_java_util_jar_Attributes__24Name$object	*SIGNATURE__5fVERSION;
	struct _jc_java_util_jar_Attributes__24Name$object	*SPECIFICATION__5fTITLE;
	struct _jc_java_util_jar_Attributes__24Name$object	*SPECIFICATION__5fVENDOR;
	struct _jc_java_util_jar_Attributes__24Name$object	*SPECIFICATION__5fVERSION;
};
extern _jc_java_util_jar_Attributes__24Name$fields_struct _jc_java_util_jar_Attributes__24Name$class_fields;

// Constructors
extern void _jc_java_util_jar_Attributes__24Name$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_util_jar_Attributes__24Name$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_jar_Attributes__24Name$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_jar_Attributes__24Name$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_jar_Attributes__24Name$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_jar_Attributes__24Name$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_jar_Attributes__24Name$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_util_jar_Attributes__24Name$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_jar_Attributes__24Name$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_jar_Attributes__24Name$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_util_jar_Attributes__24Name$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_util_jar_Attributes__24Name$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_jar_Attributes__24Name$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_jar_Attributes__24Name$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_jar_Attributes__24Name$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_util_jar_Attributes__24Name$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_jar_Attributes__24Name$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_jar_Attributes__24Name$vmethods	java_util_jar_Attributes__24Name;
};

// Vtype
struct _jc_java_util_jar_Attributes__24Name$vtype {
	_jc_type			type;
	_jc_java_util_jar_Attributes__24Name$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_jar_Attributes__24Name$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*origName;
};

// Reference instance fields (object)
struct _jc_java_util_jar_Attributes__24Name$refs {
    _jc_java_util_jar_Attributes__24Name$sub_refs	java_util_jar_Attributes__24Name;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_jar_Attributes__24Name$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_jar_Attributes__24Name$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_jar_Attributes__24Name$sub_nonrefs	java_util_jar_Attributes__24Name;
};

// Object instance structure
struct _jc_java_util_jar_Attributes__24Name$object {
	_jc_java_util_jar_Attributes__24Name$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_jar_Attributes__24Name$vtype	*vtype;
	_jc_java_util_jar_Attributes__24Name$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_jar_Attributes__24Name$vtype _jc_java_util_jar_Attributes__24Name$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_jar_Attributes__24Name, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_jar_Attributes__24Name$class_object;

#endif	/* _JC_java_util_jar_Attributes__24Name_H_ */
